#!/usr/bin/perl -w
# -*- cperl -*-

#
# Author: Slaven Rezic
#

use strict;
use Test::More 'no_plan';

use_ok 'CPAN::Test::Dummy::Perl5::BuildRequires';
use_ok 'CPAN::Test::Dummy::Perl5::Make';

__END__
