# -*- perl -*-

#
# Author: Slaven Rezic
#
# Copyright (C) 2018,2024 Slaven Rezic. All rights reserved.
# This package is free software; you can redistribute it and/or
# modify it under the same terms as Perl itself.
#
# Mail: slaven@rezic.de
# WWW:  http://www.rezic.de/eserte/
#

=head1 NAME

CPAN::Test::Dummy::Perl5::BuildRequires - Dummy test module with a build_requires dependency

=cut

package CPAN::Test::Dummy::Perl5::BuildRequires;

use strict;
use warnings;
our $VERSION = '0.02';

1;

__END__
